# DelphiFMX4Python
Delphi's FireMonkey framework as a Python module for Windows, MacOS, Linux, and Android GUI development.

<b>About:</b>

The delphifmx library is provided by the [Python4Delphi library](https://github.com/pyscripter/python4delphi) as a standard Python module.

<b>Python installation requirements on Linux:</b>

It uses the Python interpreter, requiring Python to be compiled with the "--enable-shared" flag.
<br>Make sure you've set the "LD_LIBRARY_PATH" and "PATH" environment variables and that Python loads the same libpython.so used by delphifmx.
* Check out the [scripts directory](https://github.com/Embarcadero/DelphiFMX4Python/tree/main/scripts) for further instructions in how to install Python or for an automated installation process. 

<b>Installation:</b>

    pip install delphifmx
   
<b>Supports:</b>
* Win32 x86, Win64 x86, Linux64 x86, Android64, and macOS64 architecturtes
* Python cp36, cp37, cp38, cp39

Also check out [DelphiVCL4Python](https://github.com/Embarcadero/DelphiVCL4Python).

Powered by [Embarcadero Delphi](https://www.embarcadero.com/products/delphi) and the [Python4Delphi library](https://github.com/pyscripter/python4delphi).

